@@ -21,7 +21,7 @@ https://microsoft.github.io/language-server-protocol/specification
 
 -- Workspace --
 
-Class attributes are named with camel-case notation because client is expecting
+Class attributes are named with camel case notation because client is expecting
 that.
 """
 import enum
@@ -32,12 +32,13 @@ from pygls.lsp.types.basic_structures import (Model, NumType, PartialResultParam
                                               VersionedTextDocumentIdentifier,
                                               WorkDoneProgressOptions, WorkDoneProgressParams,
                                               WorkspaceEdit)
-from pygls.lsp.types.language_features.document_symbol import WorkspaceCapabilitiesSymbolKind
+from pygls.lsp.types.language_features.document_symbol import (WorkspaceCapabilitiesSymbolKind,
+                                                               WorkspaceCapabilitiesTagSupport)
 
 
 class WorkspaceFoldersServerCapabilities(Model):
-    supported: Optional[bool] = False
-    change_notifications: Optional[Union[bool, str]] = None
+    supported: Optional[bool]
+    change_notifications: Optional[Union[bool, str]]
 
 
 class WorkspaceFolder(Model):
@@ -55,7 +56,7 @@ class DidChangeWorkspaceFoldersParams(Model):
 
 
 class DidChangeConfigurationClientCapabilities(Model):
-    dynamic_registration: Optional[bool] = False
+    dynamic_registration: Optional[bool]
 
 
 class DidChangeConfigurationParams(Model):
@@ -63,8 +64,8 @@ class DidChangeConfigurationParams(Model):
 
 
 class ConfigurationItem(Model):
-    scope_uri: Optional[str] = None
-    section: Optional[str] = None
+    scope_uri: Optional[str]
+    section: Optional[str]
 
 
 class ConfigurationParams(Model):
@@ -72,7 +73,7 @@ class ConfigurationParams(Model):
 
 
 class DidChangeWatchedFilesClientCapabilities(Model):
-    dynamic_registration: Optional[bool] = False
+    dynamic_registration: Optional[bool]
 
 
 class WatchKind(enum.IntFlag):
@@ -83,7 +84,7 @@ class WatchKind(enum.IntFlag):
 
 class FileSystemWatcher(Model):
     glob_pattern: str
-    kind: Optional[WatchKind] = WatchKind.Create | WatchKind.Change | WatchKind.Delete
+    kind: Optional[WatchKind]
 
 
 class DidChangeWatchedFilesRegistrationOptions(Model):
@@ -106,8 +107,9 @@ class DidChangeWatchedFilesParams(Model):
 
 
 class WorkspaceSymbolClientCapabilities(Model):
-    dynamic_registration: Optional[bool] = False
-    symbol_kind: Optional[WorkspaceCapabilitiesSymbolKind] = None
+    dynamic_registration: Optional[bool]
+    symbol_kind: Optional[WorkspaceCapabilitiesSymbolKind]
+    tag_support: Optional[WorkspaceCapabilitiesTagSupport]
 
 
 class WorkspaceSymbolOptions(WorkDoneProgressOptions):
@@ -123,7 +125,7 @@ class WorkspaceSymbolParams(WorkDoneProgressParams, PartialResultParams):
 
 
 class ExecuteCommandClientCapabilities(Model):
-    dynamic_registration: Optional[bool] = False
+    dynamic_registration: Optional[bool]
 
 
 class ExecuteCommandOptions(WorkDoneProgressOptions):
@@ -136,17 +138,17 @@ class ExecuteCommandRegistrationOptions(ExecuteCommandOptions):
 
 class ExecuteCommandParams(WorkDoneProgressParams):
     command: str
-    arguments: Optional[List[Any]] = None
+    arguments: Optional[List[Any]]
 
 
 class ApplyWorkspaceEditParams(Model):
     edit: WorkspaceEdit
-    label: Optional[str] = None
+    label: Optional[str]
 
 
 class ApplyWorkspaceEditResponse(Model):
     applied: bool
-    failure_reason: Optional[str] = None
+    failure_reason: Optional[str]
 
 
 class DidOpenTextDocumentParams(Model):
@@ -154,9 +156,9 @@ class DidOpenTextDocumentParams(Model):
 
 
 class TextDocumentContentChangeEvent(Model):
-    range: Optional[Range] = None
-    range_length: Optional[NumType] = None
-    text: str = ''
+    range: Optional[Range]
+    range_length: Optional[NumType]
+    text: str
 
 
 class TextDocumentContentChangeTextEvent(Model):
@@ -181,12 +183,12 @@ class WillSaveTextDocumentParams(Model):
 
 
 class SaveOptions(Model):
-    include_text: bool = False
+    include_text: Optional[bool]
 
 
 class DidSaveTextDocumentParams(Model):
     text_document: TextDocumentIdentifier
-    text: Optional[str] = None
+    text: Optional[str]
 
 
 class DidCloseTextDocumentParams(Model):
@@ -194,7 +196,7 @@ class DidCloseTextDocumentParams(Model):
 
 
 class TextDocumentSyncClientCapabilities(Model):
-    dynamic_registration: Optional[bool] = False
-    will_save: Optional[bool] = False
-    will_save_wait_until: Optional[bool] = False
-    did_save: Optional[bool] = False
+    dynamic_registration: Optional[bool]
+    will_save: Optional[bool]
+    will_save_wait_until: Optional[bool]
+    did_save: Optional[bool]
